embassy-usb-driver

Crates

git

Versions

default

Flavors

HostError

Enum HostError 

pub enum HostError {
    ChannelError(ChannelError),
    RequestFailed,
    InvalidDescriptor,
    OutOfSlots,
    OutOfChannels,
    NoSuchDevice,
    InsufficientMemory,
    Other(&'static str),
}
Indicates type of error of Host interface

Variants



ChannelError(ChannelError)

A channel-level transfer error occurred.



RequestFailed

The control request was not acknowledged by the device.



InvalidDescriptor

A descriptor returned by the device could not be parsed.



OutOfSlots

No free device slots available.



OutOfChannels

No free host channels available.



NoSuchDevice

The addressed device does not exist.



InsufficientMemory

Insufficient memory for the requested operation.



Other(&'static str)

An unspecified error with a static description.